@@ -685,6 +685,11 @@ vte_sequence_handler_decset_internal(VteTerminal *terminal,
 		 GINT_TO_POINTER(0),
 		 GINT_TO_POINTER(MOUSE_TRACKING_ALL_MOTION_TRACKING),
 		 NULL, NULL,},
+		/* 1006: Extended mouse coordinates. */
+		{1006, &terminal->pvt->mouse_xterm_extension, NULL, NULL,
+		 GINT_TO_POINTER(FALSE),
+		 GINT_TO_POINTER(TRUE),
+		 NULL, NULL,},
 		/* 1010/rxvt: disallowed, scroll-on-output is set by user. */
 		{1010, NULL, NULL, NULL, NULL, NULL, NULL, NULL,},
 		/* 1011/rxvt: disallowed, scroll-on-keypress is set by user. */
@@ -2296,6 +2301,9 @@ vte_sequence_handler_character_attributes (VteTerminal *terminal, GValueArray *p
 			terminal->pvt->screen->defaults.attr.half = 1;
 			terminal->pvt->screen->defaults.attr.bold = 0;
 			break;
+		case 3:
+			terminal->pvt->screen->defaults.attr.italic = 1;
+			break;
 		case 4:
 			terminal->pvt->screen->defaults.attr.underline = 1;
 			break;
@@ -2316,6 +2324,9 @@ vte_sequence_handler_character_attributes (VteTerminal *terminal, GValueArray *p
 			terminal->pvt->screen->defaults.attr.bold = 0;
 			terminal->pvt->screen->defaults.attr.half = 0;
 			break;
+		case 23:
+			terminal->pvt->screen->defaults.attr.italic = 0;
+			break;
 		case 24:
 			terminal->pvt->screen->defaults.attr.underline = 0;
 			break;
